def bubble_sort(alist):
    for passnum in range(len(alist)-1,0,-1):
        for i in range(passnum):
            if alist[i]>alist[i+1]:
                temp = alist[i]
                alist[i] = alist[i+1]
                alist[i+1] = temp



def insertion_sort(alist):
   for index in range(1,len(alist)):

     currentvalue = alist[index]
     position = index

     while position>0 and alist[position-1]>currentvalue:
         alist[position]=alist[position-1]
         position = position-1

     alist[position]=currentvalue


def selection_sort(alist):
   for fillslot in range(len(alist)-1,0,-1):
       positionOfMax=0
       for location in range(1,fillslot+1):
           if alist[location]>alist[positionOfMax]:
               positionOfMax = location

       temp = alist[fillslot]
       alist[fillslot] = alist[positionOfMax]
       alist[positionOfMax] = temp


from bubble_sort import bubble_sort
from selection_sort import selection_sort
from insertion_sort import insertion_sort
from quick_sort import quick_sort
import argparse
import ast

parser = argparse.ArgumentParser()
parser.add_argument('list')
parser.add_argument('--bub', dest='algorithm', action='store_const', const=bubble_sort, default=bubble_sort)
parser.add_argument('--sel', dest='algorithm', action='store_const', const=selection_sort, default=bubble_sort)
parser.add_argument('--ins', dest='algorithm', action='store_const', const=insertion_sort, default=bubble_sort)
parser.add_argument('--qui', dest='algorithm', action='store_const', const=quick_sort, default=bubble_sort)

if __name__ == '__main__':
    args = parser.parse_args()
    alist = ast.literal_eval(args.list)
    fn = args.algorithm
    fn(alist)
    print(alist)


from setuptools import setup

setup(name='sorts_pr',
      version='0.1.0',
      description='four sorting functions',
      long_description='includes 4 sorting functions bubble sort, selection sort, insertion sort and quick sort',
      keywords='sort bubble selection insertion quick',
      url='https://gitlab.propulsion-home.ch/pascal_rueegger/daily_work/tree/week3day4/week3/day4/sorts_pr',
      author='Pascal Rueegger',
      author_email='pascalrueegger@gmx.ch',
      license='MIT',
      packages=['sorts_pr'],
      install_requires=[],
      include_package_data=True,
      zip_safe=False,
      test_suite='nose.collector',
      tests_require=['nose'],
      )


def quick_sort(alist):
   quick_sort_helper(alist,0,len(alist)-1)


def quick_sort_helper(alist,first,last):
   if first<last:

       splitpoint = partition(alist,first,last)

       quick_sort_helper(alist,first,splitpoint-1)
       quick_sort_helper(alist,splitpoint+1,last)


def partition(alist,first,last):
   pivotvalue = alist[first]

   leftmark = first+1
   rightmark = last

   done = False
   while not done:

       while leftmark <= rightmark and alist[leftmark] <= pivotvalue:
           leftmark = leftmark + 1

       while alist[rightmark] >= pivotvalue and rightmark >= leftmark:
           rightmark = rightmark -1

       if rightmark < leftmark:
           done = True
       else:
           temp = alist[leftmark]
           alist[leftmark] = alist[rightmark]
           alist[rightmark] = temp

   temp = alist[first]
   alist[first] = alist[rightmark]
   alist[rightmark] = temp
   return rightmark